@@ -10,7 +10,7 @@
  */
 app_data_t* app_init() {
     app_data_t *myapp;
-	const gchar *myrawext[] = {"PEF","DNG","NEF","ARW","CR2","CRW","RAF","DCR","MRW","ORF","SRF","SR2","MOS",NULL};
+	const gchar *myrawext[] = {"PEF","pef","DNG","dng","NEF","nef","ARW","arw","CR2","cr2","CRW","crw","RAF","raf","DCR","dcr","MRW","mrw","ORF","orf","SRF","srf","SR2","sr2","MOS","mos",NULL};
 	guint i;
 
 	myapp = g_new(app_data_t,1);
