@@ -12,21 +12,14 @@
 /*
  * Functions declaration
  */
-void load_image(app_data_t *myapp,gchar *imgfname);
-gboolean scale_image(GtkWidget *callerobj,app_data_t *myapp);
 void open_image_file(GtkWidget *callerobj,app_data_t *myapp);
 void load_next_image(GtkWidget *callerobj,app_data_t *myapp);
 void load_prev_image(GtkWidget *callerobj,app_data_t *myapp);
 void toggle_prev_next_menu_button(const gchar *mode,app_data_t *myapp);
 void toggle_fullscreen_mode(GtkWidget *callerobj,app_data_t *myapp);
-void store_filenames_in_dir(app_data_t *myapp);
 gboolean detect_button_press_on_image (GtkWidget *eventbox,GdkEventButton *event,app_data_t *myapp);
 gboolean detect_hardware_key_press (GtkWidget *widget,GdkEventKey *event,app_data_t *myapp);
 gboolean detect_main_window_changes (GObject *object,GdkEvent *event,app_data_t *myapp);
 DBusHandlerResult detect_mce_signal (DBusConnection *conn,DBusMessage *msg,app_data_t *myapp);
-gboolean draw_prev_next_arrow(app_data_t *myapp);
 gboolean draw_image_details(GtkWidget *self,GdkEventExpose *event,app_data_t *myapp);
 void destroy_app (GtkWidget *callerobj,app_data_t *myapp);
-void ungrab_volume_keys(GtkWidget *widget);
-void save_configuration (app_data_t *myapp);
-void load_configuration (app_data_t *myapp);
