@@ -18,49 +18,27 @@
 /* Includes */
 #include <gtk/gtkmain.h>
 #include <hildon/hildon.h>
-#include <libosso.h>
 #include <string.h>
 #include <stdlib.h>
 
 #include "localisation.h"
+#include "appdata.h"
 #include "interface.h"
+#ifdef HAVE_CONFIG_H
 #include "../config.h"
+#endif
 
 int main(int argc,char* argv[]) {
-    app_data_t myapp;
-    osso_context_t *osso_cont;
-    const gchar *myrawext[] = {"PEF","DNG","NEF","ARW","CR2","CRW","RAF","DCR","MRW","ORF","SRF","SR2","MOS",NULL};
-
-    /* Initialize OSSO context */
-    osso_cont = osso_initialize(PACKAGE,VERSION,TRUE,NULL);
-	if (osso_cont == NULL) {
-		fprintf(stderr,"OSSO context initialization failed.\n");
-    	exit(1);
-    }
+    app_data_t *myapp;
 
     /* Initialize Hildon and GTK environments */
-    hildon_gtk_init(&argc, &argv);
-
-    /* Initialize application's structure */
-    myapp.imgbuffer = NULL;
-    myapp.allimgindir = NULL;
-    myapp.currdir = NULL;
-    myapp.currfname = NULL;
-    myapp.currfindex = 0;
-    myapp.imgparam = NULL;
-    myapp.imgparamwin = NULL;
-    myapp.pressbuttontime = 0;
-    myapp.rawext = myrawext;
-    myapp.actioninprog = NONE;
-    myapp.zoomlevel = FIT_SCREEN;
-
+    hildon_gtk_init(&argc,&argv);
+    /* Initialize application's data */
+    myapp = app_init();
     /* Create application's UI */
-    create_app(&myapp);
-
-    /* Begin the main application */
+    create_app(myapp);
+    /* Begin the main application's loop */
     gtk_main();
-
     /* Exit */
-    osso_deinitialize(osso_cont);
     return 0;
 }
